(setq load-history
      (nconc load-history
             '(("ediff-hook" ediff-menu ediff-merge-menu epatch-menu ediff-misc-menu ediff-window-setup-function ediff-xemacs-init-menus menu-bar-ediff-misc-menu menu-bar-epatch-menu menu-bar-ediff-merge-menu menu-bar-ediff-menu (provide . ediff-hook))
               ("vc-hooks" vc-ignore-vc-files vc-master-templates vc-header-alist vc-handled-backends vc-path vc-make-backup-files vc-follow-symlinks vc-display-status vc-consult-headers vc-keep-workfiles vc-mistrust-permissions vc-mistrust-permissions vc-mode vc-error-occurred vc-file-prop-obarray vc-touched-properties vc-file-setprop vc-file-getprop vc-file-clearprops vc-make-backend-sym vc-find-backend-function vc-call-backend vc-call vc-parse-buffer vc-insert-file vc-registered vc-backend vc-backend-subdirectory-name vc-name vc-checkout-model vc-user-login-name vc-state vc-up-to-date-p vc-default-state-heuristic vc-workfile-unchanged-p vc-default-workfile-unchanged-p vc-workfile-version vc-default-registered vc-possible-master vc-check-master-templates vc-toggle-read-only vc-default-make-version-backups-p vc-version-backup-file-name vc-delete-automatic-version-backups vc-make-version-backup vc-before-save vc-after-save vc-mode-line vc-default-mode-line-string vc-follow-link vc-find-file-hook vc-file-not-found-hook vc-kill-buffer-hook vc-prefix-map (provide . vc-hooks))
               ("float-sup" pi e degrees-to-radians radians-to-degrees degrees-to-radians radians-to-degrees (provide . lisp-float-type))
               ("buff-menu" Buffer-menu-buffer-column Buffer-menu-mode-map Buffer-menu-mode Buffer-menu-revert Buffer-menu-revert-function Buffer-menu-buffer buffer-menu buffer-menu-other-window Buffer-menu-mark Buffer-menu-unmark Buffer-menu-backup-unmark Buffer-menu-delete Buffer-menu-delete-backwards Buffer-menu-save Buffer-menu-not-modified Buffer-menu-execute Buffer-menu-select Buffer-menu-visit-tags-table Buffer-menu-1-window Buffer-menu-mouse-select Buffer-menu-this-window Buffer-menu-other-window Buffer-menu-switch-other-window Buffer-menu-2-window Buffer-menu-toggle-read-only Buffer-menu-bury Buffer-menu-view Buffer-menu-view-other-window list-buffers list-buffers-noselect)
               ("abbrev" only-global-abbrevs abbrev-mode abbrev-mode edit-abbrevs-map kill-all-abbrevs insert-abbrevs list-abbrevs abbrev-table-name prepare-abbrev-list-buffer edit-abbrevs-mode edit-abbrevs edit-abbrevs-redefine define-abbrevs read-abbrev-file quietly-read-abbrev-file write-abbrev-file add-mode-abbrev add-global-abbrev add-abbrev inverse-add-mode-abbrev inverse-add-global-abbrev inverse-add-abbrev abbrev-prefix-mark expand-region-abbrevs)
               ("replace" case-replace query-replace-history query-replace-interactive query-replace-from-history-variable query-replace-to-history-variable query-replace-read-args query-replace query-replace-regexp query-replace-regexp-eval map-query-replace-regexp replace-string replace-regexp regexp-history delete-non-matching-lines delete-matching-lines count-matches keep-lines-read-args keep-lines flush-lines how-many occur-mode-map occur-buffer occur-nlines occur-command-arguments occur-mode-map occur-mode-syntax-table occur-mode-abbrev-table occur-mode occur-revert-function occur-mode-mouse-goto occur-mode-find-occurrence occur-mode-goto-occurrence occur-next occur-prev list-matching-lines-default-context-lines list-matching-lines list-matching-lines-face occur query-replace-help query-replace-map replace-match-string-symbols replace-eval-replacement replace-loop-through-replacements perform-replace query-replace-highlight replace-overlay replace-dehighlight replace-highlight)
               ("textmodes/fill" fill-individual-varying-indent sentence-end-double-space colon-double-space sentence-end-without-period fill-paragraph-function enable-kinsoku set-fill-prefix adaptive-fill-mode adaptive-fill-regexp adaptive-fill-first-line-regexp adaptive-fill-function fill-indent-according-to-mode current-fill-column canonically-space-region fill-common-string-prefix fill-context-prefix fill-nobreak-predicate fill-find-break-point fill-region-as-paragraph skip-line-prefix fill-paragraph fill-region default-justification current-justification set-justification set-justification-none set-justification-left set-justification-right set-justification-full set-justification-center justify-current-line unjustify-current-line unjustify-region fill-nonuniform-paragraphs fill-individual-paragraphs fill-individual-paragraphs-prefix fill-individual-paragraphs-citation)
               ("textmodes/text-mode" text-mode-hook text-mode-variant text-mode-syntax-table text-mode-abbrev-table text-mode-map text-mode paragraph-indent-text-mode paragraph-indent-minor-mode indented-text-mode text-mode-hook-identify toggle-text-mode-auto-fill center-paragraph center-region center-line)
               ("emacs-lisp/lisp-mode" lisp-mode-abbrev-table emacs-lisp-mode-syntax-table lisp-mode-syntax-table lisp-imenu-generic-expression lisp-mode-variables lisp-outline-level lisp-mode-shared-map emacs-lisp-mode-map emacs-lisp-byte-compile emacs-lisp-byte-compile-and-load emacs-lisp-mode-hook lisp-mode-hook lisp-interaction-mode-hook emacs-lisp-mode-map emacs-lisp-mode-syntax-table emacs-lisp-mode-abbrev-table emacs-lisp-mode lisp-mode-map lisp-mode-map lisp-mode-syntax-table lisp-mode-abbrev-table lisp-mode lisp-eval-defun lisp-interaction-mode-map lisp-interaction-mode-map lisp-interaction-mode-syntax-table lisp-interaction-mode-abbrev-table lisp-interaction-mode eval-print-last-sexp last-sexp-setup-props last-sexp-toggle-display eval-last-sexp-1 eval-last-sexp eval-defun-1 eval-defun-2 eval-defun lisp-comment-indent lisp-mode-auto-fill lisp-indent-offset lisp-indent-function lisp-indent-line calculate-lisp-indent-last-sexp calculate-lisp-indent lisp-indent-function lisp-body-indent lisp-indent-specform lisp-indent-defform indent-sexp lisp-indent-region lisp-fill-paragraph indent-code-rigidly (provide . lisp-mode))
               ("textmodes/paragraphs" use-hard-newlines use-hard-newlines paragraph-start paragraph-separate sentence-end page-delimiter paragraph-ignore-fill-prefix forward-paragraph backward-paragraph mark-paragraph kill-paragraph backward-kill-paragraph transpose-paragraphs start-of-paragraph-text end-of-paragraph-text forward-sentence backward-sentence kill-sentence backward-kill-sentence mark-end-of-sentence transpose-sentences)
               ("register" register-alist get-register set-register point-to-register window-configuration-to-register frame-configuration-to-register register-to-point jump-to-register register-swap-out number-to-register increment-register view-register insert-register copy-to-register append-to-register prepend-to-register copy-rectangle-to-register)
               ("textmodes/page" forward-page backward-page mark-page narrow-to-page count-lines-page what-page (provide . page))
               ("emacs-lisp/lisp" defun-prompt-regexp parens-require-spaces forward-sexp-function forward-sexp backward-sexp mark-sexp forward-list backward-list down-list backward-up-list up-list kill-sexp backward-kill-sexp beginning-of-defun-function beginning-of-defun beginning-of-defun-raw end-of-defun-function buffer-end end-of-defun mark-defun narrow-to-defun insert-parentheses move-past-close-and-reindent check-parens lisp-complete-symbol)
               ("startup" command-line-processed inhibit-startup-message inhibit-startup-echo-area-message inhibit-default-init command-switch-alist command-line-args-left command-line-functions command-line-default-directory command-line-x-option-alist before-init-hook after-init-hook emacs-startup-hook term-setup-hook keyboard-type window-setup-hook initial-major-mode init-file-user site-run-file mail-host-address user-mail-address auto-save-list-file-prefix init-file-debug init-file-had-error normal-top-level-add-subdirs-inode-list normal-top-level-add-subdirs-to-load-path normal-top-level-add-to-load-path normal-top-level precompute-menubar-bindings tty-long-option-alist tool-bar-images-pixel-height tool-bar-originally-present tty-handle-args command-line initial-scratch-message fancy-splash-text fancy-splash-delay fancy-splash-max-time fancy-splash-image fancy-current-text fancy-splash-help-echo fancy-splash-stop-time fancy-splash-insert fancy-splash-head fancy-splash-tail fancy-splash-screens-1 fancy-splash-default-action fancy-splash-screens use-fancy-splash-screens-p startup-echo-area-message display-startup-echo-area-message command-line-1 command-line-normalize-file-name)
               ("paths.el" prune-directory-list Info-default-directory-list news-path news-inews-program gnus-default-nntp-server gnus-nntp-service gnus-local-organization gnus-startup-file rmail-file-name rmail-spool-directory sendmail-program remote-shell-program term-file-prefix abbrev-file-name)
               ("menu-bar" buffers-menu-max-size menu-bar-help-menu menu-bar-tools-menu menu-bar-options-menu menu-bar-edit-menu menu-bar-files-menu menu-bar-file-menu nonincremental-search-forward nonincremental-search-backward nonincremental-re-search-forward nonincremental-re-search-backward nonincremental-repeat-search-forward nonincremental-repeat-search-backward nonincremental-repeat-re-search-forward nonincremental-repeat-re-search-backward menu-bar-search-menu menu-bar-adv-search-menu menu-bar-goto-menu yank-menu menu-bar-kill-ring-save clipboard-yank clipboard-kill-ring-save clipboard-kill-region menu-bar-enable-clipboard menu-bar-custom-menu menu-bar-make-toggle menu-bar-options-save send-mail-item-name read-mail-item-name menu-bar-games-menu vc-menu-map menu-bar-describe-menu menu-bar-manuals-menu kill-this-buffer kill-this-buffer-enabled-p delete-frame-enabled-p yank-menu-length menu-bar-update-yank-menu menu-bar-select-yank list-buffers-directory menu-bar-update-buffers-maxbuf menu-bar-select-buffer menu-bar-select-frame menu-bar-update-buffers-1 menu-bar-buffers-menu-list-buffers-entry menu-bar-update-buffers menu-bar-mode menu-bar-mode (provide . menu-bar))
               ("isearch" search-exit-option search-slow-window-lines search-slow-speed search-upper-case search-nonincremental-instead search-whitespace-regexp search-highlight search-invisible isearch-hide-immediately isearch-mode-hook isearch-mode-end-hook search-ring regexp-search-ring search-ring-max regexp-search-ring-max search-ring-yank-pointer regexp-search-ring-yank-pointer search-ring-update isearch-mode-map minibuffer-local-isearch-map isearch-forward isearch-regexp isearch-word isearch-cmds isearch-string isearch-message isearch-success isearch-invalid-regexp isearch-within-brackets isearch-other-end isearch-wrapped isearch-barrier isearch-just-started isearch-case-fold-search isearch-original-minibuffer-message-timeout isearch-adjusted isearch-slow-terminal-mode isearch-small-window isearch-opoint isearch-window-configuration isearch-yank-flag isearch-op-fun isearch-recursive-edit isearch-nonincremental isearch-new-forward isearch-opened-overlays isearch-input-method-function isearch-input-method-local-p isearch-mode isearch-forward isearch-forward-regexp isearch-backward isearch-backward-regexp isearch-mode-help isearch-mode isearch-update isearch-done isearch-update-ring isearch-exit isearch-edit-string isearch-nonincremental-exit-minibuffer isearch-forward-exit-minibuffer isearch-reverse-exit-minibuffer isearch-cancel isearch-abort isearch-repeat isearch-repeat-forward isearch-repeat-backward isearch-toggle-regexp isearch-toggle-case-fold isearch-delete-char isearch-yank-string isearch-yank-kill isearch-yank-x-selection isearch-mouse-2 isearch-yank-word isearch-yank-line isearch-search-and-update isearch-*-char isearch-|-char isearch-other-control-char isearch-other-meta-char isearch-quote-char isearch-return-char isearch-printing-char isearch-whitespace-chars isearch-process-search-char isearch-process-search-string isearch-ring-adjust1 isearch-ring-adjust isearch-ring-advance isearch-ring-retreat isearch-ring-advance-edit isearch-ring-retreat-edit isearch-complete1 isearch-complete isearch-complete-edit isearch-top-state isearch-pop-state isearch-push-state isearch-message isearch-message-prefix isearch-message-suffix isearch-search isearch-open-overlay-temporary isearch-open-necessary-overlays isearch-clean-overlays isearch-intersects-p isearch-close-unnecessary-overlays isearch-range-invisible isearch-overlay isearch-highlight isearch-dehighlight isearch-no-upper-case-p isearch-text-char-description isearch-unread (require . timer) isearch-lazy-highlight isearch-lazy-highlight-cleanup isearch-lazy-highlight-initial-delay isearch-lazy-highlight-interval isearch-lazy-highlight-max-at-a-time isearch isearch-lazy-highlight-face isearch-lazy-highlight-overlays isearch-lazy-highlight-wrapped isearch-lazy-highlight-start isearch-lazy-highlight-end isearch-lazy-highlight-timer isearch-lazy-highlight-last-string isearch-lazy-highlight-window isearch-lazy-highlight-window-start isearch-lazy-highlight-case-fold-search isearch-lazy-highlight-regexp isearch-lazy-highlight-cleanup isearch-lazy-highlight-new-loop isearch-lazy-highlight-search isearch-lazy-highlight-update isearch-resume)
               ("timer" timer-create timerp timer-set-time timer-set-idle-time timer-next-integral-multiple-of-time timer-relative-time timer-inc-time timer-set-time-with-usecs timer-set-function timer-activate timer-activate-when-idle disable-timeout cancel-timer cancel-function-timers timer-event-last-2 timer-event-last-1 timer-event-last timer-max-repeats timer-until timer-event-handler timeout-event-p run-at-time run-with-timer add-timeout run-with-idle-timer with-timeout-handler with-timeout y-or-n-p-with-timeout timer-duration-words timer-duration (provide . timer))
               ("facemenu" (provide . facemenu) facemenu-keybindings facemenu-new-faces-at-end facemenu-unlisted-faces facemenu-face-menu facemenu-face-menu facemenu-foreground-menu facemenu-foreground-menu facemenu-background-menu facemenu-background-menu facemenu-special-menu facemenu-special-menu facemenu-justification-menu facemenu-justification-menu facemenu-indentation-menu facemenu-indentation-menu facemenu-menu facemenu-menu facemenu-keymap facemenu-keymap facemenu-add-face-function facemenu-end-add-face facemenu-remove-face-function facemenu-color-alist facemenu-update facemenu-set-face facemenu-set-foreground facemenu-set-background facemenu-set-face-from-menu facemenu-set-invisible facemenu-set-intangible facemenu-set-read-only facemenu-remove-face-props facemenu-remove-all facemenu-remove-special list-text-properties-at facemenu-read-color list-colors-display facemenu-color-equal facemenu-add-face facemenu-active-faces facemenu-get-face facemenu-add-new-face facemenu-complete-face-list facemenu-iterate)
               ("faces" (require . cus-face) face-font-selection-order face-font-family-alternatives face-font-registry-alternatives face-list make-face make-empty-face copy-face internal-find-face internal-get-face facep check-face face-id face-equal face-differs-from-default-p face-nontrivial-p face-x-resources set-face-attribute-from-resource set-face-attributes-from-resources make-face-x-resource-internal face-name face-attribute face-foreground face-background face-stipple face-background-pixmap face-underline-p face-inverse-video-p face-bold-p face-italic-p face-documentation set-face-documentation face-doc-string set-face-doc-string set-face-attribute make-face-bold make-face-unbold make-face-italic make-face-unitalic make-face-bold-italic set-face-font set-face-background set-face-foreground set-face-stipple set-face-underline set-face-underline-p set-face-inverse-video-p set-face-bold-p set-face-italic-p set-face-background-pixmap invert-face read-face-name face-valid-attribute-values face-attribute-name-alist face-descriptive-attribute-name face-read-string face-read-integer read-face-attribute read-face-font read-all-face-attributes modify-face read-face-and-attribute list-faces-sample-text list-faces-display describe-face face-attr-construct face-spec-set-match-display face-spec-choose face-spec-reset-face face-spec-set face-attr-match-p face-spec-match-p face-default-spec face-user-default-spec defined-colors x-defined-colors color-defined-p x-color-defined-p color-values x-color-values display-color-p x-display-color-p display-grayscale-p frame-background-mode frame-set-background-mode x-handle-named-frame-geometry x-handle-reverse-video x-create-frame-with-faces face-set-after-frame-default tty-handle-reverse-video tty-create-frame-with-faces tty-set-up-initial-frame-faces frame-update-faces frame-update-face-colors x-font-regexp x-font-regexp-head x-font-regexp-weight x-font-regexp-slant x-font-regexp-weight-subnum x-font-regexp-slant-subnum x-font-regexp-swidth-subnum x-font-regexp-adstyle-subnum x-resolve-font-name x-frob-font-weight x-frob-font-slant x-make-font-bold x-make-font-demibold x-make-font-unbold x-make-font-italic x-make-font-oblique x-make-font-unitalic x-make-font-bold-italic (provide . faces))
               ("cus-face" custom-facep custom-declare-face custom-face-attributes custom-face-attributes-get custom-set-faces (provide . cus-face))
               ("term/tty-colors" color-name-rgb-alist tty-standard-colors tty-defined-color-alist tty-color-alist tty-modify-color-alist tty-color-canonicalize tty-color-define tty-color-clear tty-color-off-gray-diag tty-color-approximate tty-color-translate tty-color-by-index tty-color-values tty-color-desc tty-color-gray-shades)
               ("frame" frame-creation-function initial-frame-alist minibuffer-frame-alist pop-up-frame-alist special-display-frame-alist special-display-popup-frame handle-delete-frame frame-initial-frame frame-initial-frame-alist frame-initial-geometry-arguments frame-initialize frame-notice-user-settings frame-notice-user-settings make-initial-minibuffer-frame get-other-frame next-multiframe-window previous-multiframe-window make-frame-on-display make-frame-command before-make-frame-hook after-make-frame-functions after-setting-font-hook new-frame make-frame filtered-frame-list minibuffer-frame-list frames-on-display-list framep-on-display frame-remove-geometry-params focus-follows-mouse select-frame-set-input-focus other-frame make-frame-names-alist frame-name-history select-frame-by-name current-frame-configuration set-frame-configuration frame-height frame-width set-default-font set-frame-font set-background-color set-foreground-color set-cursor-color set-mouse-color set-border-color auto-raise-mode auto-lower-mode set-frame-name display-mouse-p display-popup-menus-p display-graphic-p display-images-p display-multi-frame-p display-multi-font-p display-selections-p display-screens display-pixel-height display-pixel-width display-mm-height display-mm-width display-backing-store display-save-under display-planes display-color-cells display-visual-class screen-height screen-width set-screen-width set-screen-height delete-other-frames show-trailing-whitespace automatic-hscrolling blink-cursor-delay blink-cursor-interval blink-cursor-idle-timer blink-cursor-timer blink-cursor-mode blink-cursor-mode blink-cursor blink-cursor-start blink-cursor-timer-function blink-cursor-end display-hourglass hourglass-delay cursor-in-non-selected-windows (provide . frame))
               ("window" one-window-p walk-windows get-window-with-predicate some-window minibuffer-window-active-p save-selected-window count-windows window-safely-shrinkable-p balance-windows split-window-keep-point split-window-vertically view-return-to-alist split-window-save-restore-data split-window-horizontally set-window-text-height enlarge-window-horizontally shrink-window-horizontally window-buffer-height count-screen-lines fit-window-to-buffer shrink-window-if-larger-than-buffer kill-buffer-and-window quit-window)
               ("indent" standard-indent indent-line-function tab-always-indent indent-according-to-mode indent-for-tab-command insert-tab indent-rigidly indent-line-to current-left-margin move-to-left-margin indent-to-left-margin delete-to-left-margin set-left-margin set-right-margin alter-text-property increase-left-margin decrease-left-margin increase-right-margin decrease-right-margin beginning-of-line-text indent-region-function indent-region indent-relative-maybe indent-relative tab-stop-list edit-tab-stops-map edit-tab-stops-buffer edit-tab-stops edit-tab-stops-note-changes tab-to-tab-stop move-to-tab-stop)
               ("international/ucs-tables" ucs-mule-8859-to-ucs-table ucs-mule-8859-to-mule-unicode ucs-8859-1-encode-table ucs-8859-2-encode-table ucs-8859-3-encode-table ucs-8859-4-encode-table ucs-8859-5-encode-table ucs-8859-7-encode-table ucs-8859-8-encode-table ucs-8859-9-encode-table ucs-8859-14-encode-table ucs-8859-15-encode-table translation-table-for-input ucs-unify-8859 ucs-fragment-8859 ucs-insert unify-8859-on-encoding-mode unify-8859-on-encoding-mode unify-8859-on-encoding-mode-hook unify-8859-on-decoding-mode unify-8859-on-decoding-mode unify-8859-on-decoding-mode-hook ucs-quail-activate ucs-minibuffer-setup (provide . ucs-tables))
               ("language/misc-lang" (provide . misc-lang))
               ("language/vietnamese" viet-viscii-decode-table viet-vscii-decode-table ccl-decode-viscii ccl-encode-viscii ccl-encode-viscii-font ccl-decode-vscii ccl-encode-vscii ccl-encode-vscii-font (provide . vietnamese))
               ("language/tibetan" tibetan-composable-pattern tibetan-consonant-transcription-alist tibetan-vowel-transcription-alist tibetan-modifier-transcription-alist tibetan-precomposed-transcription-alist tibetan-subjoined-transcription-alist tibetan-base-to-subjoined-alist tibetan-composite-vowel-alist tibetan-precomposition-rule-alist tibetan-obsolete-glyphs tibetan-regexp tibetan-precomposed-regexp tibetan-precomposition-rule-regexp tibetan-decomposed tibetan-decomposed-temp (provide . tibetan))
               ("composite" reference-point-alist encode-composition-rule decode-composition-rule encode-composition-components decode-composition-components compose-region decompose-region compose-string decompose-string compose-chars find-composition compose-chars-after compose-last-chars decompose-composite-char)
               ("language/thai" (provide . thai))
               ("language/lao" (provide . lao))
               ("language/korean" (provide . korean))
               ("language/japanese" (provide . japanese))
               ("language/hebrew" (provide . hebrew))
               ("language/greek" (provide . greek))
               ("language/romanian" (provide . romanian))
               ("language/slovak" (provide . slovak))
               ("language/czech" (provide . czech))
               ("language/european" decode-mac-roman encode-mac-roman (provide . european))
               ("language/ethiopic" ccl-encode-ethio-font (provide . ethiopic))
               ("language/english")
               ("language/devanagari" devanagari-1-column-char (provide . devanagari))
               ("language/indian" indian-itrans-consonant-alist indian-itrans-vowel-sign-alist indian-itrans-other-letters-alist indian-itrans-regexp itrans-indian-regexp indian-itrans-alist indian-decode-itrans-region indian-encode-itrans-region (provide . indian))
               ("language/cyrillic" cyrillic-koi8-r-decode-table ccl-decode-koi8 ccl-encode-koi8 ccl-encode-koi8-font cyrillic-alternativnyj-decode-table ccl-decode-alternativnyj ccl-encode-alternativnyj ccl-encode-alternativnyj-font (provide . cyrillic))
               ("language/chinese" post-read-decode-hz pre-write-encode-hz ccl-encode-big5-font (provide . chinese))
               ("international/latin-9")
               ("international/latin-8")
               ("international/latin-5")
               ("international/latin-4")
               ("international/latin-3")
               ("international/latin-2")
               ("international/latin-1")
               ("international/characters")
               ("international/utf-16" utf-16-decode-ucs ccl-decode-mule-utf-16-le ccl-decode-mule-utf-16-be utf-16-decode-to-ucs ccl-encode-mule-utf-16-le ccl-encode-mule-utf-16-be)
               ("international/utf-8" ucs-mule-to-mule-unicode ccl-decode-mule-utf-8 ccl-encode-mule-utf-8)
               ("case-table" set-case-syntax-offset set-case-syntax-set-multibyte describe-buffer-case-table copy-case-table set-case-syntax-1 set-case-syntax-delims set-case-syntax-pair set-case-syntax (provide . case-table))
               ("international/mule-cmds" mule-keymap mule-menu-keymap describe-language-environment-map setup-language-environment-map set-coding-system-map help-xref-mule-regexp-template coding-system-change-eol-conversion coding-system-change-text-conversion toggle-enable-multibyte-characters view-hello-file universal-coding-system-argument set-default-coding-systems update-iso-coding-systems prefer-coding-system sort-coding-systems-predicate sort-coding-systems find-coding-systems-region find-coding-systems-string find-coding-systems-for-charsets find-multibyte-characters last-coding-system-specified select-safe-coding-system-accept-default-p select-safe-coding-system select-message-coding-system language-info-alist get-language-info set-language-info set-language-info-alist read-language-name leim-list-file-name leim-list-header leim-list-entry-regexp update-leim-list-functions update-leim-list-file current-input-method current-input-method-title default-input-method input-method-history inactivate-current-input-method-function describe-current-input-method-function input-method-alist register-input-method read-input-method-name activate-input-method inactivate-input-method set-input-method toggle-input-method describe-input-method describe-current-input-method read-multilingual-string input-method-verbose-flag input-method-highlight-flag input-method-activate-hook input-method-inactivate-hook input-method-after-insert-chunk-hook input-method-exit-on-first-char input-method-use-echo-area input-method-exit-on-invalid-key set-language-environment-hook exit-language-environment-hook setup-specified-language-environment current-language-environment reset-language-environment set-display-table-and-terminal-coding-system set-language-environment standard-display-european-internal set-language-environment-coding-systems princ-list describe-specified-language-support describe-language-environment locale-translation-file-name locale-language-names locale-charset-language-names locale-preferred-coding-systems locale-name-match set-locale-environment get-charset-property put-charset-property char-code-property-table get-char-code-property put-char-code-property iso-2022-control-alist encoded-string-description encode-coding-char)
               ("help" help-map help-mode-map help-xref-stack help-xref-stack-item help-mode-hook help-mode help-mode-setup help-mode-finish help-quit help-with-tutorial string-key-binding describe-key-briefly help-return-method print-help-return-message describe-key describe-mode describe-distribution describe-copying describe-project describe-no-warranty describe-prefix-bindings view-emacs-news view-order-manuals view-emacs-FAQ view-emacs-problems view-lossage help help-for-help-doc help-for-help function-called-at-point symbol-file-load-history-loaded load-symbol-file-load-history symbol-file describe-function describe-function-1 variable-at-point help-xref-on-pp describe-variable describe-bindings where-is locate-library help-highlight-p help-highlight-face help-back-label help-xref-symbol-regexp help-xref-mule-regexp help-xref-info-regexp help-setup-xref help-xref-following help-make-xrefs help-xref-button help-insert-xref-button help-xref-interned help-xref-mode help-follow-mouse help-xref-go-back help-go-back help-follow help-next-ref help-previous-ref temp-buffer-max-height temp-buffer-resize-mode temp-buffer-resize-mode temp-buffer-resize-mode-hook resize-temp-buffer-window help-manyarg-func-alist (provide . help))
               ("loaddefs.el" add-log-full-name add-log-mailing-address add-log-lisp-like-modes add-log-c-like-modes add-log-tex-like-modes ad-redefinition-action ad-default-compilation-action ange-ftp-re-read-dir appt-issue-message appt-message-warning-time appt-audible appt-visible appt-display-mode-line appt-msg-window appt-display-duration appt-display-diary auto-show-mode autoarg-mode autoarg-kp-mode auto-insert-mode auto-revert-mode global-auto-revert-mode mouse-avoidance-mode \` binhex-begin-line bookmark-map bookmark-locate list-bookmarks edit-bookmarks menu-bar-bookmark-map menu-bar-bookmark-map browse-url-browser-function browse-url-new-window-flag browse-url-netscape-display browse-url-save-file browse-url-generic-program browse-url-grail calendar-week-start-day calendar-offset view-diary-entries-initially number-of-diary-entries mark-diary-entries-in-calendar calendar-remove-frame-by-deleting view-calendar-holidays-initially mark-holidays-in-calendar all-hebrew-calendar-holidays all-christian-calendar-holidays all-islamic-calendar-holidays calendar-load-hook initial-calendar-window-hook today-visible-calendar-hook today-invisible-calendar-hook calendar-move-hook diary-file diary-nonmarking-symbol hebrew-diary-entry-symbol islamic-diary-entry-symbol diary-include-string sexp-diary-entry-symbol abbreviated-calendar-year european-calendar-style american-date-diary-pattern european-date-diary-pattern european-calendar-display-form american-calendar-display-form print-diary-entries-hook list-diary-entries-hook diary-hook diary-display-hook nongregorian-diary-listing-hook mark-diary-entries-hook nongregorian-diary-marking-hook diary-list-include-blanks holidays-in-diary-buffer general-holidays oriental-holidays local-holidays other-holidays hebrew-holidays-1 hebrew-holidays-2 hebrew-holidays-3 hebrew-holidays-4 hebrew-holidays christian-holidays islamic-holidays solar-holidays calendar-setup c-mode-syntax-table c++-mode-syntax-table objc-mode-syntax-table java-mode-syntax-table idl-mode-syntax-table pike-mode-syntax-table c-emacs-features custom-print-functions compilation-mode-hook compilation-window-height compilation-process-setup-function compilation-buffer-name-function compilation-finish-function compilation-finish-functions compilation-ask-about-save compilation-search-path partial-completion-mode reference-point-alist crisp-mode brief-mode customize-variable customize-variable-other-window custom-file pending-delete-mode delete-selection-mode diff-switches diff-command dired-listing-switches dired-chown-program dired-ls-F-marks-symlinks dired-trivial-filenames dired-keep-marker-rename dired-keep-marker-copy dired-keep-marker-hardlink dired-keep-marker-symlink dired-dwim-target dired-copy-preserve-time double-mode easy-mmode-define-minor-mode ebnf-despool edebug-all-defs edebug-all-forms edebug-defun ediff3 ediff ebuffers ebuffers3 edirs edir-revisions edirs3 edirs-merge edir-merge-revisions edir-merge-revisions-with-ancestor edirs-merge-with-ancestor ediff-merge ediff-merge-with-ancestor epatch epatch-buffer erevision ediff-window-setup-function ediff-xemacs-init-menus eregistry edmacro-eight-bits eldoc-mode eldoc-minor-mode-string menu-bar-emerge-menu tags-file-name tags-case-fold-search tags-table-list tags-compression-info-list tags-add-tables find-tag-hook find-tag-default-function eudc-tools-menu facemenu-face-menu facemenu-face-menu facemenu-foreground-menu facemenu-foreground-menu facemenu-background-menu facemenu-background-menu facemenu-special-menu facemenu-special-menu facemenu-justification-menu facemenu-justification-menu facemenu-indentation-menu facemenu-indentation-menu facemenu-menu facemenu-menu fast-lock-mode ffap find-ls-option find-grep-options flyspell-mode-line-string flyspell-mode-map global-font-lock-mode fortran-tab-mode-default gnus-batch-kill three-step-help hi-lock-mode highlight-lines-matching-regexp highlight-regexp highlight-phrase unhighlight-regexp hide-ifdef-mode hide-ifdef-initially hide-ifdef-read-only hide-ifdef-lines hs-hide-comments-when-hiding-all hs-special-modes-alist highlight-changes-mode hippie-expand-try-functions-list hippie-expand-verbose hippie-expand-dabbrev-skip-space hippie-expand-dabbrev-as-symbol hippie-expand-no-restriction hippie-expand-max-buffers hippie-expand-ignore-buffers hippie-expand-only-buffers global-hl-line-mode image-file-name-extensions image-file-name-regexps auto-image-file-mode imenu-sort-function imenu-generic-expression imenu-create-index-function imenu-prev-index-position-function imenu-extract-index-name-function imenu-name-lookup-function imenu-default-goto-function inferior-lisp-filter-regexp inferior-lisp-program inferior-lisp-load-command inferior-lisp-prompt inferior-lisp-mode-hook run-lisp xemacsp version18p version20p ispell-personal-dictionary ispell-local-dictionary-alist ispell-dictionary-alist ispell-menu-map ispell-menu-xemacs ispell-menu-map-needed ispell-skip-region-alist ispell-tex-skip-alists iswitchb-mode auto-compression-mode kkc-after-update-conversion-functions default-korean-keyboard landmark-repeat landmark latin1-display ledit-save-files ledit-go-to-lisp-string ledit-go-to-liszt-string lpr-windows-system lpr-lp-system printer-name lpr-switches lpr-command mail-hist-keep-history mail-use-rfc822 mail-complete-style manual-entry message-from-style message-signature-separator message-user-organization-file message-send-mail-function message-citation-line-function message-yank-prefix message-cite-function message-indent-citation-function message-signature message-signature-file mh-mime-content-types minibuffer-electric-default-mode msb-mode string-to-list string-to-vector truncate-string nested-alist-p mouse-wheel-mode ifconfig indent-for-comment set-comment-column kill-comment indent-new-comment-line comment-column comment-start comment-start-skip comment-end-skip comment-end comment-indent-function comment-style comment-padding comment-multi-line disabled-command-hook run-octave show-paren-mode pc-selection-mode pcomplete/gdb pcomplete/pushd pcomplete/time cvs-dired-action cvs-dired-use-hook cvs-dired-noselect cvs-global-menu edit-picture bdf-directory-list ps-multibyte-buffer ps-paper-type quickurl-reread-hook-postfix recentf-mode close-rectangle rmail-dont-reply-to-names rmail-default-dont-reply-to-names rmail-ignored-headers rmail-displayed-headers rmail-retry-ignored-headers rmail-highlighted-headers rmail-highlight-face rmail-delete-after-output rmail-primary-inbox-list rmail-mail-new-frame rmail-secondary-file-directory rmail-secondary-file-regexp rmail-confirm-expunge rmail-mode-hook rmail-get-new-mail-hook rmail-show-message-hook rmail-quit-hook rmail-delete-message-hook rmail-file-coding-system rmail-enable-mime rmail-show-mime-function rmail-insert-mime-forwarded-message-function rmail-insert-mime-resent-message-function rmail-search-mime-message-function rmail-search-mime-header-function rmail-mime-feature rmail-decode-mime-charset rmail-mime-charset-pattern rmail-output-file-alist rmail-fields-not-to-output rmail-summary-scroll-between-messages rmail-summary-line-count-flag rmail-summary-line-decoder rmail-user-mail-address-regexp resize-minibuffer-mode resize-minibuffer-window-max-height resize-minibuffer-window-exactly resize-minibuffer-frame resize-minibuffer-frame-max-height resize-minibuffer-frame-exactly scroll-all-mode mail-from-style mail-specify-envelope-from mail-self-blind mail-interactive mail-yank-ignored-headers send-mail-function mail-header-separator mail-archive-file-name mail-default-reply-to mail-alias-file mail-personal-alias-file mail-signature sendmail-coding-system default-sendmail-coding-system shell-script-mode shell-dumb-shell-regexp skeleton-filter calendar-time-display-form calendar-latitude calendar-longitude calendar-location-name speedbar strokes-mode global-set-stroke describe-stroke load-user-strokes tex-shell-file-name tex-directory tex-first-line-header-regexp tex-main-file tex-offer-save tex-run-command latex-run-command slitex-run-command tex-start-options-string latex-block-names tex-bibtex-command tex-dvi-print-command tex-alt-dvi-print-command tex-dvi-view-command tex-show-queue-command tex-default-mode tex-open-quote tex-close-quote TeX-mode plain-TeX-mode LaTeX-mode texinfo-open-quote texinfo-close-quote display-time-day-and-date display-time-mode disable-timeout tool-bar-mode tooltip-mode trace-buffer type-break-mode type-break-interval type-break-good-rest-interval type-break-keystroke-threshold vc-checkout-hook vc-checkin-hook vc-before-checkin-hook vc-cvs-registered vc-rcs-master-templates vc-rcs-registered vc-sccs-master-templates vc-sccs-registered vc-sccs-search-project-dir view-mode which-func-mode which-function-mode whitespace-global-mode winner-mode)
               ("files" delete-auto-save-files directory-abbrev-alist make-backup-files backup-inhibited backup-by-copying backup-by-copying-when-linked backup-by-copying-when-mismatch backup-by-copying-when-privileged-mismatch normal-backup-enable-predicate backup-enable-predicate buffer-offer-save find-file-existing-other-name find-file-visit-truename revert-without-query buffer-file-number buffer-file-numbers-unique temporary-file-directory small-temporary-file-directory null-device file-name-invalid-regexp file-precious-flag version-control dired-kept-versions delete-old-versions kept-old-versions kept-new-versions require-final-newline auto-save-default auto-save-visited-file-name auto-save-file-name-transforms save-abbrevs find-file-run-dired find-directory-functions find-file-not-found-hooks find-file-hooks write-file-hooks local-write-file-hooks write-contents-hooks enable-local-variables local-enable-local-variables enable-local-eval view-read-only ange-ftp-completion-hook-function convert-standard-filename pwd cd-path parse-colon-path cd-absolute cd load-file load-library file-local-copy file-truename file-chase-links switch-to-buffer-other-window switch-to-buffer-other-frame find-file find-file-other-window find-file-other-frame find-file-read-only find-file-read-only-other-window find-file-read-only-other-frame find-alternate-file-other-window find-alternate-file create-file-buffer generate-new-buffer automount-dir-prefix abbreviated-home-dir abbreviate-file-name find-file-not-true-dirname-list find-buffer-visiting find-file-wildcards find-file-suppress-same-file-warnings find-file-noselect find-file-noselect-1 insert-file-contents-literally insert-file-literally find-file-literally find-file-literally after-find-file-from-revert-buffer after-find-file normal-mode auto-mode-alist interpreter-mode-alist inhibit-first-line-modes-regexps inhibit-first-line-modes-suffixes auto-mode-interpreter-regexp set-auto-mode hack-local-variables-prop-line hack-local-variables-hook hack-local-variables ignored-local-variables risky-local-variable-p hack-one-local-variable-quotep hack-one-local-variable change-major-mode-with-file-name set-visited-file-name write-file backup-buffer file-name-sans-versions file-ownership-preserved-p file-name-sans-extension file-name-extension make-backup-file-name-function backup-directory-alist make-backup-file-name make-backup-file-name-1 backup-file-name-p backup-extract-version-start backup-extract-version find-backup-file-name file-nlinks file-relative-name save-buffer delete-auto-save-file-if-necessary auto-save-hook after-save-hook save-buffer-coding-system basic-save-buffer basic-save-buffer-1 basic-save-buffer-2 save-some-buffers not-modified toggle-read-only insert-file append-to-file file-newest-backup rename-uniquely make-directory revert-buffer-function revert-buffer-insert-file-contents-function before-revert-hook after-revert-hook revert-buffer-internal-hook revert-buffer recover-file recover-session recover-session-finish kill-some-buffers auto-save-mode rename-auto-save-file make-auto-save-file-name auto-save-file-name-p wildcard-to-regexp list-directory-brief-switches list-directory-verbose-switches file-expand-wildcards list-directory shell-quote-wildcard-pattern insert-directory-program insert-directory insert-directory-safely kill-emacs-query-functions confirm-kill-emacs save-buffers-kill-emacs file-name-non-special)
               ("simple" fundamental-mode newline set-hard-newline-properties open-line split-line delete-indentation join-line delete-blank-lines delete-trailing-whitespace newline-and-indent reindent-then-newline-and-indent quoted-insert forward-to-indentation backward-to-indentation back-to-indentation fixup-whitespace delete-horizontal-space just-one-space beginning-of-buffer end-of-buffer mark-whole-buffer goto-line count-lines-region what-line count-lines what-cursor-position read-expression-map read-expression-history eval-expression-print-level eval-expression-print-length eval-expression-debug-on-error eval-expression edit-and-eval-command repeat-complex-command minibuffer-history minibuffer-history-sexp-flag minibuffer-history-search-history minibuffer-text-before-history minibuffer-history-initialize minibuffer-avoid-prompt minibuffer-history-case-insensitive-variables previous-matching-history-element next-matching-history-element minibuffer-temporary-goal-position next-history-element previous-history-element next-complete-history-element previous-complete-history-element minibuffer-prompt-width minibuffer-prompt-end minibuffer-contents minibuffer-contents-no-properties delete-minibuffer-contents advertised-undo undo pending-undo-list undo-in-progress undo-more undo-copy-list undo-copy-list-1 undo-start undo-adjusted-markers undo-make-selective-list undo-elt-in-region undo-elt-crosses-region undo-delta shell-command-history shell-command-switch shell-command-default-error-buffer shell-command display-message-or-buffer shell-command-sentinel shell-command-on-region shell-command-to-string universal-argument-map universal-argument-num-events universal-argument universal-argument-more negative-argument digit-argument universal-argument-minus universal-argument-other-key interprogram-cut-function interprogram-paste-function kill-ring kill-ring-max kill-ring-yank-pointer kill-new kill-append current-kill kill-read-only-ok kill-region copy-region-as-kill kill-ring-save append-next-kill yank-pop yank rotate-yank-pointer kill-forward-chars kill-backward-chars backward-delete-char-untabify-method backward-delete-char-untabify zap-to-char kill-whole-line kill-line forward-visible-line end-of-visible-line insert-buffer append-to-buffer prepend-to-buffer copy-to-buffer mark deactivate-mark set-mark mark-ring mark-ring-max global-mark-ring global-mark-ring-max set-mark-command push-mark pop-mark exchange-dot-and-mark exchange-point-and-mark transient-mark-mode pop-global-mark next-line-add-newlines next-line previous-line track-eol goal-column temporary-goal-column line-move-ignore-invisible line-move set-goal-column scroll-other-window-down beginning-of-buffer-other-window end-of-buffer-other-window transpose-chars transpose-words transpose-sexps transpose-lines transpose-subr-start1 transpose-subr-start2 transpose-subr-end1 transpose-subr-end2 transpose-subr transpose-subr-1 backward-word mark-word kill-word backward-kill-word current-word fill-prefix auto-fill-inhibit-regexp comment-line-break-function do-auto-fill normal-auto-fill-function auto-fill-mode auto-fill-function turn-on-auto-fill turn-off-auto-fill set-fill-column set-selective-display overwrite-mode-textual overwrite-mode-binary overwrite-mode binary-overwrite-mode line-number-mode line-number-mode column-number-mode column-number-mode blink-matching-paren blink-matching-paren-on-screen blink-matching-paren-distance blink-matching-delay blink-matching-paren-dont-ignore-comments blink-matching-open keyboard-quit buffer-quit-function keyboard-escape-quit read-mail-command mail-user-agent define-mail-user-agent rfc822-goto-eoh sendmail-user-agent-compose compose-mail compose-mail-other-window compose-mail-other-frame set-variable-value-history set-variable completion-list-mode-map completion-reference-buffer completion-no-auto-exit completion-base-size delete-completion-window previous-completion next-completion choose-completion choose-completion-delete-max-match choose-completion-string completion-list-mode completion-list-mode-finish completion-setup-hook completion-setup-function switch-to-completions event-apply-alt-modifier event-apply-super-modifier event-apply-hyper-modifier event-apply-shift-modifier event-apply-control-modifier event-apply-meta-modifier event-apply-modifier clone-buffer-hook clone-process clone-buffer clone-indirect-buffer clone-indirect-buffer-other-window syntax-code-table normal-erase-is-backspace normal-erase-is-backspace-mode byte-compiling-files-p)
               ("bindings" make-mode-line-mouse-map mode-line-toggle-read-only mode-line-toggle-modified mode-line-widen mode-line-abbrev-mode mode-line-auto-fill-mode mode-line-input-method-map mode-line-coding-system-map mode-line-mule-info mode-line-buffer-identification mode-line-frame-identification mode-line-process mode-line-modified mode-line-buffer-identification-keymap mode-line-minor-mode-keymap mode-line-mode-menu-keymap mode-line-unbury-buffer mode-line-bury-buffer mode-line-other-buffer mode-line-mode-menu mode-line-mode-menu-1 mode-line-mode-name bound-and-true-p mode-line-mode-menu propertized-buffer-identification minor-mode-alist complete-symbol mode-specific-command-prefix mode-specific-map point-to-register-compatibility-binding jump-to-register-compatibility-binding copy-to-register-compatibility-binding insert-register-compatibility-binding)
               ("format" format-alist format-encode-run-method format-decode-run-method format-annotate-function format-decode format-decode-buffer format-decode-region format-encode-buffer format-encode-region format-write-file format-find-file format-insert-file format-read format-replace-strings format-delq-cons format-make-relatively-unique format-common-tail format-proper-list-p format-reorder format-deannotate-region format-subtract-regions format-property-increment-region format-insert-annotations format-annotate-value format-annotate-region format-annotate-location format-annotate-single-property-change format-annotate-atomic-property-change (provide . format))
               ("international/mule-conf.el" non-standard-icccm-encodings-alist ctext-post-read-conversion non-standard-designations-alist ctext-pre-write-conversion)
               ("international/mule" mule-version mule-version-date load-with-code-conversion charset-quoted-standard-p charsetp charset-info charset-id charset-bytes charset-dimension charset-chars charset-width charset-direction charset-iso-final-char charset-iso-graphic-plane charset-reverse-charset charset-short-name charset-long-name charset-description charset-plist set-charset-plist make-char charset-list generic-char-p decode-char encode-char coding-spec-type-idx coding-spec-mnemonic-idx coding-spec-doc-string-idx coding-spec-plist-idx coding-spec-flags-idx coding-system-spec coding-system-type coding-system-mnemonic coding-system-doc-string coding-system-plist coding-system-flags coding-system-get coding-system-put coding-system-category coding-system-base coding-system-parent coding-system-eol-type coding-system-lessp add-to-coding-system-list coding-system-list map-charset-chars register-char-codings make-subsidiary-coding-system transform-make-coding-system-args make-coding-system define-coding-system-alias set-buffer-file-coding-system default-terminal-coding-system set-terminal-coding-system default-keyboard-coding-system set-keyboard-coding-system keyboard-coding-system set-buffer-process-coding-system set-clipboard-coding-system set-selection-coding-system last-next-selection-coding-system set-next-selection-coding-system set-coding-priority auto-coding-alist auto-coding-regexp-alist set-auto-coding-for-load auto-coding-alist-lookup auto-coding-from-file-contents set-auto-coding after-insert-file-set-buffer-file-coding-system find-new-buffer-file-coding-system modify-coding-system-alist make-translation-table make-translation-table-from-vector define-translation-table with-category-table (provide . mule))
               ("cus-start")
               ("env" read-envvar-name-history read-envvar-name setenv-history setenv getenv (provide . env))
               ("map-ynp" map-y-or-n-p)
               ("emacs-lisp/backquote" (provide . backquote) backquote-list*-function backquote-list*-macro backquote-list* backquote-backquote-symbol backquote-unquote-symbol backquote-splice-symbol backquote \` backquote-process backquote-listify)
               ("custom" custom-define-hook custom-initialize-default custom-initialize-set custom-initialize-reset custom-initialize-changed custom-declare-variable defcustom defface custom-declare-group defgroup custom-add-to-group custom-handle-all-keywords custom-handle-keyword custom-add-dependencies custom-add-option custom-add-link custom-add-version custom-add-load custom-local-buffer custom-set-variables custom-set-default read-quoted-char-radix (provide . custom))
               ("widget" define-widget-keywords define-widget widget-plist-member (provide . widget))
               ("version.el" emacs-version emacs-major-version emacs-minor-version emacs-build-time emacs-build-system emacs-version version)
               ("subr" custom-declare-variable-list custom-declare-variable-early lambda push pop when unless dolist dotimes caar cadr cdar cddr last butlast nbutlast remove remq assoc-default assoc-ignore-case assoc-ignore-representation member-ignore-case undefined suppress-keymap key-substitution-in-progress substitute-key-definition define-key-after kbd keyboard-translate global-map esc-map ctl-x-map ctl-x-4-map ctl-x-4-prefix ctl-x-5-map ctl-x-5-prefix listify-key-sequence-1 listify-key-sequence eventp event-modifiers event-basic-type mouse-movement-p event-start event-end event-click-count posn-window posn-point posn-x-y posn-col-row posn-timestamp dot dot-marker dot-min dot-max window-dot set-window-dot read-input send-string send-region show-buffer buffer-flush-undo eval-current-buffer compiled-function-p define-function sref baud-rate focus-frame unfocus-frame string= string< move-marker not rplaca rplacd beep indent-to-column backward-delete-char search-forward-regexp search-backward-regexp int-to-string store-match-data point-at-eol point-at-bol string-to-int make-local-hook add-hook remove-hook add-to-list eval-after-load eval-next-after-load read-quoted-char-radix read-quoted-char read-passwd force-mode-line-update momentary-string-display font-lock-defaults suspend-hook suspend-resume-hook buffer-file-type get-buffer-window-list ignore error user-original-login-name start-process-shell-command with-current-buffer with-temp-file with-temp-message with-temp-buffer with-output-to-string combine-after-change-calls with-syntax-table save-match-data-internal save-match-data match-string match-string-no-properties split-string subst-char-in-string replace-regexp-in-string shell-quote-argument make-syntax-table add-to-invisibility-spec remove-from-invisibility-spec global-set-key local-set-key global-unset-key local-unset-key frame-configuration-p functionp interactive-form assq-delete-all make-temp-file add-minor-mode)
               ("byte-run" defsubst make-obsolete make-obsolete-variable dont-compile eval-when-compile eval-and-compile)
)))
